function facpack
% The toolbox FACPACK provides software for the following problems in
% multivariate curve resolution:
% 1. baseline correction,
% 2. computation of 2- and 3-component factorizations and the area of feasible
%    solutions,
% 3. computation of 4-component factorizations and the area of feasible
%    solutions,
% 4. generalized Borgen plots for the computation of the AFS for data 
%    including slightly negative entries
% 5. combination of complementarity and AFS for 3-component systems
% 6. combination of complementarity and AFS for 4-component systems
% 7. peak group analysis for the extraction of pure component spectra
% 8. FACPACK library to view, export, add or delete pure component spectra
%    or concentration profiles
% Copyright (c) 2013 Mathias Sawall, Annekathrin Juerss, University of Rostock, Department of Mathematics.
% 
% The software can be used for academic, research and other similar noncommercial uses. The user
% acknowledges that this software is still in the development stage and that it is provided by the
% copyright holders and contributors "as is" and any express or implied warranties, fitness for a
% particular purpose are disclaimed. In no event shall the copyright owner or contributors be liable
% for any direct, indirect, incidental, special, exemplary, or consequential damages.
% 
% The copyright holders provide no reassurances that the source code provided does not infringe any
% patent, copyright, or any other intellectual property rights of third parties. The copyright
% holders disclaim any liability to any recipient for claims brought against recipient by any third
% party for infringement of that parties intellectual property rights.
% 
% The user has to respect the lapack license, see http://www.netlib.org/lapack/LICENSE.txt, and
% the license for the ACM routine nl2sol, see http://www.acm.org/publications/policies/softwarecrnotice,
% which are used in the associated C-code. Furthermore the user has to respect the license for the 
% file Mouse3D.m from the Mathworks File Exchange, see 
% http://www.mathworks.com/matlabcentral/fileexchange/view_license?file_info_id=18266

version = 1.3;
fname = mfilename;
calcf = mfilename('fullpath');
calcf = calcf(1:end-length(fname));
calcfp = [calcf, 'subfcnsFP'];
path(path, calcf);
path(path, calcfp);

fig = figure(10);
pause(.1);

scrsz = get(0,'ScreenSize');

set(fig,'Position',[scrsz(3)/4 scrsz(4)/3 scrsz(3)/2 scrsz(4)/2]);

pause(.5);
figpos = get(fig,'Position');

set(fig,'Name',['FACPACK (version ',num2str(version, '%2.2f'),'-alpha)'],'NumberTitle','off','MenuBar','none','Toolbar','none','color','white');

if ispc
    basicfsz = 5;
    basichi = 0.06;
else
    basicfsz = 6;
    basichi = 0.05;
end

Styles = {'bitstream charter';'clean';'Courier';'courier 10 pitch';'frank ruehl';'Helvetica';'Helvetica-Narrow';'itc bookman';'urw bookman l'};
sty = Styles{6};
bgc = 0.95*ones(3,1);

nt = 1;
nb = 1;

na = 8;
ha = 0.8/na;
fa = 1.2;
hz = 0.985;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Correct the baseline for one spectrum or a series of spectra. Choose an interval, in which the baseline is corrected for all spectra.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Computation of 2- and 3-component factorizations and the area of feasible solutions by the (inverse) polygon inflation algorithm.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Computation of 4-component factorizations and the area of feasible solutions by the ray casting algorithm.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Compute Borgen plots for nonnegative spectral data and Generalized Borgen plots for spectral data including small negative matrix components.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Apply duality/complementarity theorem to the AFS for 3-component systems. Simultaneous presentation of "C" and "A" in a live view mode.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Apply duality/complementarity theorem to the AFS for 4-component systems. Simultaneous presentation of "C" and "A" in a live view mode.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Analyze peak groups to identify correlations between peaks. Compose peak groups to a factor "A" and compute best fit factor "C".'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Enter the FACPACK library to view, export, add or delete pure component spectra.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, hz-fa*nt*ha, 0.5, ha]);
nt = nt+1;



Button(nt) = uicontrol('Style','pushbutton','String','Baseline correction','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonBLA, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','AFS computation (2 and 3 components)','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonAFS, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','AFS computation (4 components)','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonRAY, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','Generalized Borgen plots','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonBKP, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','Duality/Complementarity & AFS (3 components)','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonCAA, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','Duality/Complementarity & AFS (4 components)','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonCA4, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','Peak group analysis','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonPGA, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','Enter FACPACK library','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.025, hz-fa*nb*ha, 0.42, ha],'Callback',{@buttonLIB, version});
nb = nb+1;


function buttonBLA(hObject, eventdata, version)
subGUI4BLA(version);

function buttonPGA(hObject, eventdata, version)
subGUI4PGA(version);

function buttonAFS(hObject, eventdata, version)
subGUI4AFS(version);

function buttonRAY(hObject, eventdata, version)
subGUI4RAY(version);

function buttonBKP(hObject, eventdata, version)
subGUI4BKP(version);

function buttonCAA(hObject, eventdata, version)
subGUI4CAA(version);

function buttonCA4(hObject, eventdata, version)
subGUI4CA4(version);

function buttonLIB(hObject, eventdata, version)
subGUI4LIB(version);
